Documentation — Scikit-HEP 0.0.1 documentation

# Documentation

This is the main page documenting the scikit-hep package, example usage, and the user API. Please refer to the links on the page about affiliated packages for their documentation.

- API
  - Constants (skhep.constants)
  - Description of datasets (skhep.dataset)
  - Mathematical utilities (skhep.math)
  - Data Modeling (skhep.modeling)
  - PDG utilities (skhep.pdg)
  - Simulation utilities (skhep.simulation)
  - Units (skhep.units)
  - Utilities (skhep.utils)
  - Data Visualization (skhep.visual)
- Examples
  - Data Visualization Examples
- FAQ
  - What is the exact project name?
  - How to pronounce the project name?
  - How to get started contributing?
  - Is there support for PyPy?
  - Is there support for GPUs?
- Miscellaneous resources
  - Presentations

You can also search through the list of modules or the full index:

- Module Index
- Index